fnss.topologies.topology.read_topology — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.3.2 documentation »
- API Reference »
- Functions »

# fnss.topologies.topology.read_topology

`read_topology`(path, encoding='utf-8')

  Read a topology from an XML file and returns either a Topology or a DirectedTopology object

  Parameters : | path : str The path of the topology XML file to parse encoding : str, optional The encoding of the file
  Returns : | topology: Topology or DirectedTopology :

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.3.2 documentation »
- API Reference »
- Functions »